==> aria2_0.11.0.orig.tar.gz: aria2-0.11.0/src/PeerListenCommand.h <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#ifndef _D_PEER_LISTEN_COMMAND_H_
#define _D_PEER_LISTEN_COMMAND_H_

#include "BtContextAwareCommand.h"
#include "TorrentDownloadEngine.h"

class PeerListenCommand : public BtContextAwareCommand {
private:
  TorrentDownloadEngine* e;
  SocketHandle socket;
  int32_t _lowestSpeedLimit;
public:
  PeerListenCommand(int cuid,
		    TorrentDownloadEngine* e,
		    const BtContextHandle& btContext);

  ~PeerListenCommand();
  
  bool execute();

  int bindPort(int portRangeStart, int portRangeEnd);

  void setLowestSpeedLimit(int32_t speed)
  {
    _lowestSpeedLimit = speed;
  }
};

#endif // _D_PEER_LISTEN_COMMAND_H_

==> aria2-1.8.1.tar.gz: aria2-1.8.1/src/PeerListenCommand.h <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#ifndef _D_PEER_LISTEN_COMMAND_H_
#define _D_PEER_LISTEN_COMMAND_H_

#include "Command.h"
#include "SharedHandle.h"
#include "IntSequence.h"

namespace aria2 {

class DownloadEngine;
class SocketCore;

class PeerListenCommand : public Command {
private:
  DownloadEngine* e;
  SharedHandle<SocketCore> socket;
  unsigned int _lowestSpeedLimit;

  static unsigned int __numInstance;

  static PeerListenCommand* __instance;

public:
  PeerListenCommand(int32_t cuid, DownloadEngine* e);

  virtual ~PeerListenCommand();
  
  virtual bool execute();

  /**
   * Binds port. If successful, the binded port number is assinged to port and
   * returns true, otherwise port is undefined and returns false.
   */
  bool bindPort(uint16_t& port, IntSequence& seq);

  // Returns binded port
  uint16_t getPort() const;

  void setLowestSpeedLimit(unsigned int speed)
  {
    _lowestSpeedLimit = speed;
  }

  static PeerListenCommand* getInstance(DownloadEngine* e);

  static unsigned int getNumInstance()
  {
    return __numInstance;
  }
  
};

} // namespace aria2 

#endif // _D_PEER_LISTEN_COMMAND_H_
